<h1 align="center">KODB<br>
    <sup>Kmaasrud's Opinionated Document Builder</sup>
</h2>

<p align="center"><a href="https://github.com/kmaasrud/kodb/wiki/Installation">Installation</a> - <a href="https://github.com/kmaasrud/kodb/wiki/Creating-a-document">Getting started</a></p>

This is my personal and opinionated document builder script, built around my document creation workflow.

Faced with the task of writing a lot of scientific documents at university, I quickly grew tired of the old-fashioned and english-centered LaTeX document system. This led me in the direction of [Pandoc](https://pandoc.org/), and more specifically [Pandoc Markdown](https://github.com/kmaasrud/kodb/wiki/Pandoc-Markdown). Pandoc Markdown is quicker to write, easily readable in it's plain text form, minimally english-centric and simply much more sensible than writing TeX. Pair that with [Tectonic](https://tectonic-typesetting.github.io/) - a self-contained, minimal and modern TeX/LaTeX engine - and I've got the same functionality as LaTeX, but in an arguably much better package. TeX now only works as a sort of assembly language, and I can write in a more sophisticated and minimal markup-language.

However, creating a directory structure for you document, learning the Pandoc command line tool, compiling with Tectonic, keeping track of CSL styles, etc... This sounds like a lot of work, I hear you say. Enter KODB: One single tool that attempts to tie together these excellent typesetting tools, abstract away all the dirty work and give you the freedom to do what you really need to do: writing. Writing KODB was my natural response to discovering the workflow explained above, and I use it almost everyday.

Beware that KODB was initially written for personal use and is quite opinionated, but despite this I hope you too can get as much use out of it as I have. To get started, first [install KODB](https://github.com/kmaasrud/kodb/wiki/Installation) and see the [Getting started page](https://github.com/kodb/wiki/Creating-a-document). Bugs or feature suggestions are to be added as [Issues](https://github.com/kmaasrud/kodb/issues) and if you have any questions, feel free to send me an email: <km@aasrud.com>.
